@@ -5,7 +5,7 @@ use 5.006002;
 use strict;
 use warnings;
 
-our $VERSION = '0.061';
+our $VERSION = '0.062';
 
 use base qw{ Exporter };
 
@@ -15,6 +15,7 @@ use Test::More 0.88;
 
 our @EXPORT_OK = qw{
     format_pass format_time
+    magnitude
     tolerance tolerance_frac
     velocity_sanity
 };
@@ -112,6 +113,29 @@ sub format_time {
 	$parts[4] + 1, @parts[ 3, 2, 1, 0 ];
 }
 
+sub magnitude (@) {
+    my ( $tle, @arg ) = @_;
+    my ( $time, $want, $name ) = splice @arg, -3;
+    my $got;
+    eval {
+	$got = $tle->universal( $time )->magnitude( @arg );
+	defined $got
+	    and $got = sprintf '%.1f', $got;
+	1;
+    } or do {
+	@_ = "$name failed: $@";
+	goto &fail;
+    };
+    if ( defined $want ) {
+	$want = sprintf '%.1f', $want;
+	@_ = ( $got, 'eq', $want, $name );
+	goto &cmp_ok;
+    } else {
+	@_ = ( ! defined $got, $name );
+	goto &ok;
+    }
+}
+
 sub tolerance (@) {
     my ( $got, $want, $tolerance, $title, $fmtr ) = @_;
     $fmtr ||= sub { return $_[0] };
